#---------------------------------------------------------------------------
#
#   MWG - Playing screen
#
#---------------------------------------------------------------------------

from __future__ import division
from pygame import locals as pk
from pygame.transform import rotozoom
from albow.widget import Widget
from albow.resource import get_font
from humerus.main_commands import MainCommandScreen
from level_view import LevelView
from tiles import tile_images

#---------------------------------------------------------------------------

class MwgPlayScreen(MainCommandScreen):

	def __init__(self, shell):
		MainCommandScreen.__init__(self, shell)
		self.game = self.shell.game
		level_view = LevelView(self.game)
		message_view = MessageView(self)
		inventory_view = InventoryView(self)
		message_view.width = self.width
		message_view.topleft = level_view.bottomleft
		inventory_view.bottomleft = self.bottomleft
		self.add(level_view)
		self.add(message_view)
		self.add(inventory_view)
	
	def level(self):
		return self.game.playing_level
	
	def begin_frame(self):
		MainCommandScreen.begin_frame(self)
		self.invalidate()

	def key_down(self, e):
		if e.cmd or e.key == pk.K_ESCAPE:
			MainCommandScreen.key_down(self, e)
		else:
			self.level().key_down(e)

	def key_up(self, e):
		self.level().key_up(e)

#---------------------------------------------------------------------------

class MessageView(Widget):

	margin = 2
	level_name_font = get_font(15, "VeraBd.ttf")
	level_name_color = (0xc0, 0xc0, 0xc0)

	def __init__(self, client):
		Widget.__init__(self)
		self.height = self.font.get_linesize() + 2 * self.margin
		self.client = client
		
	def draw(self, surf):
		level = self.client.level()
		cell = level.cell_containing_player()
		msg = cell.message
		if msg:
			text = msg
			font = self.font
			color = self.fg_color
		else:
			num, title = self.client.game.level_number_and_title()
			text = "Level %s: %s" % (num, title)
			font = self.level_name_font
			color = self.level_name_color
		buf = font.render(text, True, color)
		frame = self.get_margin_rect()
		surf.blit(buf, frame)

#---------------------------------------------------------------------------

class InventoryView(Widget):

	margin = 2

	def __init__(self, client):
		Widget.__init__(self)
		self.height = 30
		self.client = client
	
	def draw(self, surf):
		h = self.height - 2 * self.margin
		w = (4 * h) // 3
		x = y = spacing = self.margin
		for name in self.client.level().player.inventory:
			image = tile_images[name]
			ri = image.get_rect()
			scale = min(w / ri.width, h / ri.height)
			thumb = rotozoom(image, 0.0, scale)
			rt = thumb.get_rect()
			rt.left = x
			surf.blit(thumb, rt)
			x += rt.width + spacing
